<?php

/**
 * Implementiert die Konfiguration der Netzwerkschnittstellen
 * @author Miguel Palmer <mp@beronet.com>
 */

include_once('/usr/www/include/SQLite2ToSQLite3.php');

class NetConf {

	private		$m_attr;

	private		$post_attr,
			$post_checked = 0;

	private		$isRequestRejected = 0,
			$reasonRejected = array();
	
	/**
	 * Constructor
	 */
	function __construct($m, $get = array(), $post = array(), $session = array()) {

		$this->m_attr = $m;

		if ($post['action'] == 'apply' || isset($post['httpsOnly']) )  {
			// clean post
			unset($post['a'], $post['submit'], $post['Apply'], $post['bonding-mode'], $post['bonding-miimon'], $post['bonding-updelay'], $post['bonding-downdelay']);
		
			// check post
			$list_post = array(	
						// general
						'm' => 'm', 'lan-mode' => 'select', 'dhcp' => 'bool', 'action' => 'accept', // accepting action since the checking is not necessary 
						// LAN
						'ipaddr' => 'ip4', 'netmask' => 'ip4', 'gateway' => 'ip4',
						// WAN
						'wan-dhcp' => 'bool', 'wan-ipaddr' => 'ip4', 'wan-netmask' => 'netmask', 'wan-gateway' => 'ip4',
						// DNS
						'lan_nameserver' => 'ip4', 'lan_nameserver2' => 'ip4', 'hostname' => 'hostname',
						// ADVANCED
						'lan_mtu' => 'int-range', 'ncs_mode' => 'select', 'beroAvahi-enabled' => 'bool',
						// VLAN
						'vlanenable' => 'bool', 'vlanid' => 'id', 'vlan-prio' => 'select',
						// ROUTE
						'route_net' => 'ip4', 'route_netmask' => 'netmask', 'route_gateway' => 'ip4',
						// HTTPS
						'errorCert' => 'bool', 'httpsOnly' => 'bool',
					  );

			$list_options_select = array(	
							'lan-mode' 	=> array('single', 'lan-wan', 'bonding'),
							'lan_mtu'	=> array('min' => 150, 'max' => 1500),
							'ncs_mode' 	=> array('on', 'detectonly', 'off'),
							'vlan-prio'	=> array('000', '001', '010', '011', '100', '101', '110', '111')  // TODO: can be remplaced by int-range
						    );

			$this->post_checked = 1;
			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected, $list_options_select);

			$this->isRequestRejected = !$this->post_checked;
		}
	}

	/**
	 * Speichert die Netzwerkkonfiguration
	 * @param beroAri $ba
	 * @param beroConf $bc
	 * @return string HTML Code
	 */
	function save($ba, $bc) {

		if ($this->post_attr['action'] == 'apply') {
			# configure basic network settings
			$fields = array('lan-ipaddr', 'lan-netmask', 'lan-gateway',
					'lan-nameserver', 'lan-mtu', 'lan-dhcp', 'wan-dhcp',
					'wan-ipaddr', 'wan-netmask', 'wan-gateway', 'bonding-mode',
					'bonding-miimon', 'bonding-updelay', 'bonding-downdelay');

			# delete every lan setting
			foreach ($fields as $field) {
				$bc->delete('root', $field);
			}

			$bc->set('root', 'lan-mode', sqlite_escape_string($this->post_attr['lan-mode']));

			$bc->set('root', 'lan-dhcp', sqlite_escape_string($this->post_attr['dhcp']));
			if (!in_array($bc->get('root', 'lan-dhcp'), array('yes', '1'))) {
				# configure static networking
				$bc->set('root', 'lan-ipaddr', sqlite_escape_string($this->post_attr['ipaddr']));
				$bc->set('root', 'lan-netmask', sqlite_escape_string($this->post_attr['netmask']));
				$bc->set('root', 'lan-gateway', sqlite_escape_string($this->post_attr['gateway']));
				$bc->set('root', 'lan-mtu', sqlite_escape_string(intval($this->post_attr['lan_mtu'])));
			}
			
			# configure nameservers
			if (strlen($this->post_attr['lan_nameserver']) != 0) {
				$nameserver = $this->post_attr['lan_nameserver'] . ((strlen($this->post_attr['lan_nameserver2']) != 0) ? ';' . $this->post_attr['lan_nameserver2'] : '');
				$bc->set('root', 'lan-nameserver', sqlite_escape_string($nameserver));
			} else {
				$bc->delete('root', 'lan-nameserver');
			}

			switch ($bc->get('root', 'lan-mode')) {
				case 'lan-wan':
					$bc->delete('root', 'lan-gateway');
					$bc->set('root', 'wan-dhcp', sqlite_escape_string($this->post_attr['wan-dhcp']));
					if ($this->post_attr['wan-dhcp'] != "1") {
						# configure static networking
						$bc->set('root', 'lan-dhcp', sqlite_escape_string("no"));
						$bc->set('root', 'wan-ipaddr', sqlite_escape_string($this->post_attr['wan-ipaddr']));
						$bc->set('root', 'wan-netmask', sqlite_escape_string($this->post_attr['wan-netmask']));
						$bc->set('root', 'wan-gateway', sqlite_escape_string($this->post_attr['wan-gateway']));
					}
	
					break;
				case 'bonding':
					$bc->set('root', 'bonding-mode', sqlite_escape_string($this->post_attr['bonding-mode']));
					$bc->set('root', 'bonding-miimon', sqlite_escape_string($this->post_attr['bonding-miimon']));
					$bc->set('root', 'bonding-updelay', sqlite_escape_string($this->post_attr['bonding-updelay']));
					$bc->set('root', 'bonding-downdelay', sqlite_escape_string($this->post_attr['bonding-downdelay']));
	
					break;
			}
		
			# configure misc. network settings
			$bc->set('root', 'hostname', sqlite_escape_string($this->post_attr['hostname']));
			$bc->set('root', 'ncs_mode', $this->post_attr['ncs_mode']);
			$bc->set('root', 'beroAvahi-enabled', (isset($this->post_attr['beroAvahi-enabled']) ? '1' : '0'));
	
			# configure vlan
			if (isset($this->post_attr['vlanenable'])) {
				$bc->set('root', 'vlan-enable', sqlite_escape_string($this->post_attr['vlanenable']));
				$bc->set('root', 'vlan-id', sqlite_escape_string($this->post_attr['vlanid']));
				$bc->set('root', 'vlan-prio', sqlite_escape_string($this->post_attr['vlan-prio']));
			} else {
				$bc->delete('root', 'vlan-enable');
				$bc->delete('root', 'vlan-id');
				$bc->delete('root', 'vlan-prio');
			}
			# configure routing
			$routing = '';
			for ($i = 0; $i < count($this->post_attr['route_net']); $i++) {
				if (($this->post_attr['route_net'][$i] != '') && ($this->post_attr['route_netmask'][$i] != '') && ($this->post_attr['route_gateway'][$i] != '')) {
					$routing .= ((strlen($routing) != 0) ? ',' : '') . $this->post_attr['route_net'][$i] . "/" . $this->post_attr['route_netmask'][$i] . "/" . $this->post_attr['route_gateway'][$i];
				}
			}
			$bc->set('root', 'routing', $routing);
	
			$ret = Helper::activate(3, true, $this->m_attr, ACTIVATE) .
				'<br /><div class="text-center" style="color:red;"><strong>' . NETWORK_CONFIGURATION_APPLIED_DIS . '</strong></div>' . "\n";
	
		}

		$file_error = '/tmp/error_certificate.log';
		if (isset($this->post_attr['errorCert']) && $this->post_attr['errorCert'] && file_exists($file_error))
		{
			exec('/bin/rm -f '. $file_error);
		}

		if (isset($this->post_attr['httpsOnly'])) {
			$ba->set('httpsOnly', sqlite_escape_string($this->post_attr['httpsOnly']));
			$option = 1;

			if ($_FILES["uploadfile"]["name"] != "") {
				if ($_FILES["uploadfile"]["size"] > 51200) { //50 kB
					$ret = "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>" . HTTPS_INVALID_FILE_SIZE . "</font></div>";
				}
				else {
					if (file_exists($file_error)) {
						exec('/bin/rm -f '. $file_error);
					}	
					$ret .= $this->_managePemFile($_FILES["uploadfile"]["tmp_name"], $option);
				}
			}
			$ret .= Helper::activate($option, true, $this->m_attr, ACTIVATE);
		}


		return($ret);
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string Dropdown LAN-Modus
	 */
	function mode($bc) {
		if ($bc->get('root', 'lan-ports') == 2) {
			$lan_mode = array(
				"single" => "Single mode",
				"lan-wan" => "LAN-WAN",
				"bonding" => "Ethernet bonding");
			$select = '<select class="form-control input-sm" name="lan-mode">' . "\n";
			foreach ($lan_mode as $mode => $desc) {
				$selected = ($bc->get('root', 'lan-mode') == $mode) ? 'selected' : null;
				$select .= "\t\t\t\t\t\t" . '<option value="' . $mode . '" ' . $selected . '> ' . $desc . '</option>' . "\n";
			}
			$select .= "\t\t\t\t\t" . '</select>' . "\n";
			ob_start();
			?>
			<div class='form-group' style='margin-top: 15px;'>
				<label for='bonding-mode' class='col-sm-5 control-label'><?php echo NETWORK_LAN_MODE_DIS; ?></label>
				<div class='col-sm-4'>
					<?php echo $select; ?>
				</div>
			</div>
			<?php
			return ob_get_clean();
		} else {
			return;
		}
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string HTML Formular für den Bonding Modus
	 */
	function bonding($bc) {
		$bonding_mode = array(
			"0" => "balance-rr",
			"1" => "active-backup",
			"2" => "balance-xor",
			"3" => "broadcast",
			"4" => "802.3ad",
			"5" => "balance-tlb",
			"6" => "balance-alb",
		);
		if ($bc->get('root', 'bonding-mode') == '')
			$bc->set('root', 'bonding-mode', '1');
		if ($bc->get('root', 'bonding-miimon') == '')
			$bc->set('root', 'bonding-miimon', '100');
		if ($bc->get('root', 'bonding-updelay') == '')
			$bc->set('root', 'bonding-updelay', '200');
		if ($bc->get('root', 'bonding-downdelay') == '')
			$bc->set('root', 'bonding-downdelay', '200');
		$select = '<select name="bonding-mode" class="form-control input-sm">';
		foreach ($bonding_mode as $mode => $desc) {
			$selected = ($bc->get('root', 'bonding-mode') == $mode) ? 'selected' : null;
			$select .= '<option value="' . $mode . '" ' . $selected . '> ' . $desc . ' <br>' . "\n";
		}
		$select .= '</select>';
		ob_start();
		?>
		<?php
		return ob_get_clean();
	}

	/**
	 * 
	 * @param beroConf $bc
	 * @return string HTML Formular fur den LAN-WAN Modus
	 */
	function lan_wan($bc) {
		$dhcp = $bc->get("root", "wan-dhcp");
		ob_start();
		?>
		<div id="wan">
			<p class="text-center lead"><?php echo NETWORK_WAN_SETTING_DIS; ?></p>
			<div class='form-group'>
				<div class='text-center'>
					<input type="radio" name="wan-dhcp" id="wan-dhcp" onclick="hide_wan($('#wan-static').prop('checked'));"  value="1" 
						   <?php echo ($dhcp == "1") ? 'checked' : ''; ?>>&nbsp;
					DHCP
					<input type="radio" name="wan-dhcp" id="wan-static" onclick="hide_wan($('#wan-static').prop('checked'));" value="0" 
						   <?php echo ($dhcp) ? '' : ' checked'; ?>>&nbsp;
						   <?php echo NETWORK_STATIC_DIS; ?>
				</div>
			</div>
			<div class='form-group' id="wan-ipaddr-tr">
				<label for='wan-ipaddr' class='col-sm-5 control-label'><?php echo NETWORK_IP_ADDRESS_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-ipaddr" class="form-control input-sm" type="text" size="15" id="wan-ipaddr" value="<?php echo $bc->get('root', 'wan-ipaddr'); ?>">
				</div>
			</div>
			<div class='form-group' id="wan-netmask-tr">
				<label for='wan-netmask' class='col-sm-5 control-label'><?php echo NETWORK_NETMASK_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-netmask" class="form-control input-sm" type="text" size="15" id="wan-netmask" value="<?php echo $bc->get('root', 'wan-netmask'); ?>">
				</div>
			</div>
			<div class='form-group' id="wan-gateway-tr">
				<label for='wan-gateway' class='col-sm-5 control-label'><?php echo NETWORK_GATEWAY_DIS; ?></label>
				<div class='col-sm-4'>
					<input name="wan-gateway" class="form-control input-sm" type="text" size="15" id="wan-gateway" value="<?php echo $bc->get('root', 'wan-gateway'); ?>">
				</div>
			</div>
		</div>
		<?php
		return ob_get_clean();
	}

	/**
	 *
	 * @return string Tab HTML
	 */
	function _display_tabs ($bc, $dhcp, $dns, $simple_class, $ncsDetectMode) 
	{
                $html_str =     '<br/>' . "\n" . '<br/>' . "\n" .
                                '<script>' . "\n" .
                                "\t" . '$(function() {' . "\n" .
                                "\t\t" . '$( "#tabs" ).tabs({active:0})' . "\n" .
                                "\t" . '});' . "\n" . 
                                '</script>' . "\n" .
				"\n\n" . '<!-- BEGIN TABS //-->' . "\n\n" .
				'<div id="tabs" class="">' . "\n" .
				"\t" . '<ul>' . "\n" .
				"\t\t" . '<li><a href="#tabs-1">' . NETWORK_TABLE_HEADER_DIS . '</a></li>' . "\n" .
				"\t\t" . '<li><a href="#tabs-2">' . HTTPS_TABLE_HEADER_DIS . '</a></li>' . "\n" .
				"\t\t" . '<li><a href="#tabs-3">' . NWTS_TABLE_HEADER_DIS . '</a></li>' . "\n" .
				"\t" . '</ul>' . "\n\n" .

				$this -> _display_tab1($bc, $dhcp, $dns, $simple_class, $ncsDetectMode) .
				$this -> _display_tab2() .
				$this -> _display_tab3() .

				"\n\n" . '<!-- END TABS //-->' . "\n" .
				'</div>' . "\n\n"; 

		return $html_str;
	}

	/**
	 *
	 * @return string Tab HTML
	 */
	function _display_tab1 ($bc, $dhcp, $dns, $simple_class, $ncsDetectMode)
	{
		$tab = "\t\t";

		$html_str =	"\n\n" . '<!-- BEGIN TAB1 //-->' . "\n\n" .
				'<div id="tabs-1">'. "\n";

		$html_str .=	$tab.'<form name="networkform" id="networkform" method="POST" class="form-horizontal" action="" style="margin-top: 15px;" onsubmit="return (checkvlan(vlanenable.checked));">'. "\n" .
				$tab."\t".'<input type="hidden" name="action" value="apply" />'. "\n" .

				$this -> mode($bc) . "\n" .

				$tab."\t".'<p class="text-center lead" id="header-lan">'.NETWORK_LAN_SETTING_DIS.'</p>'. "\n" .
				$tab."\t".'<p class="text-center lead" id="header-bonding">'.NETWORK_BONDING_SETTING_DIS.'</p>'. "\n" .
				$tab."\t".'<div class="form-group" id="lan-dhcp-tr">'. "\n" .
				$tab."\t\t".'<div class="text-center">'. "\n" .
				$tab."\t\t\t".'<input type="radio" name="dhcp" id="lan_dhcp" onclick="hide_netconfig(document.getElementById(\'lan_static\').checked);"'. "\n" . 
				$tab."\t\t\t\t\t\t\t\t".'data-toggle="tooltip" title="'.NET_CONF_DHCP.'" value="yes" '. (($dhcp) ? 'checked' : '') .'  />&nbsp;' . "\n" .
				$tab."\t\t\t\t".'DHCP'. "\n" .
				$tab."\t\t\t".'<input type="radio" name="dhcp" id="lan_static" onclick="hide_netconfig(document.getElementById(\'lan_static\').checked);"'. "\n" .
			   	$tab."\t\t\t\t\t\t\t\t".'data-toggle="tooltip" title="'. NET_CONF_STATIC .'" value="no" '. (($dhcp) ? '' : 'checked') .' />&nbsp;' . "\n" .
			   	$tab."\t\t\t\t". NETWORK_STATIC_DIS ."\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group" id="lan_ipaddr">'. "\n" .
				$tab."\t\t".'<label for="ipaddr" class="col-sm-5 control-label">'. NETWORK_IP_ADDRESS_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="ipaddr" class="form-control input-sm" type="text" size="15" id="ipaddr" title="'. NET_CONF_IP_ADDRESS .'" data-toggle="tooltip" value="'. $bc -> get('root', 'lan-ipaddr') .'"/>'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group" id="lan_netmask">'. "\n" .
				$tab."\t\t".'<label for="netmask" class="col-sm-5 control-label">'. NETWORK_NETMASK_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="netmask" class="form-control input-sm" type="text" size="15" id="netmask" onclick="if (netmask.value == \'\') netmask.value = makeNetMask(ipaddr.value);"'. "\n" .
				$tab."\t\t\t\t\t\t\t\t".'title="'. NET_CONF_NETMASK .'" data-toggle="tooltip" value="'. $bc -> get('root', 'lan-netmask') .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group" id="lan_gateway">'. "\n" .
				$tab."\t\t".'<label for="gateway" class="col-sm-5 control-label">'. NETWORK_GATEWAY_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="gateway" class="form-control input-sm" type="text" size="15" id="gateway" title="'. NET_CONF_GATEWAY .'" data-toggle="tooltip" value="'. $bc -> get('root', 'lan-gateway') .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				


				$this -> bonding($bc) . "\n" .
				$this -> lan_wan($bc) . "\n" .
				
				$tab."\t".'<p class="text-center lead" id="header-lan">' . NETWORK_DNS_SETTING_DIS . '</p>'. "\n" .
				$tab."\t".'<div class="form-group" id="lan_dns1">'. "\n" .
				$tab."\t\t".'<label for="lan_nameserver" class="col-sm-5 control-label">'. NETWORK_PRIMARY_NAME_SERVER_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="lan_nameserver" class="form-control input-sm" type="text" size="15" id="lan_nameserver" title="'. NET_CONF_NAMESERVER .'" data-toggle="tooltip" value="'. $dns[0] .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				
				$tab."\t".'<div class="form-group" id="lan_dns2">'. "\n" .
				$tab."\t\t".'<label for="lan_nameserver2" class="col-sm-5 control-label">'. NETWORK_SECONDARY_NAME_SERVER_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="lan_nameserver2" class="form-control input-sm" type="text" size="15" id="lan_nameserver2" title="'. NET_CONF_SECONDARY_NAMESERVER .'" data-toggle="tooltip" value="'. $dns[1] .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				
				$tab."\t".'<div class="form-group" id="lan_hostname">'. "\n" .
				$tab."\t\t".'<label for="hostname" class="col-sm-5 control-label">'. NETWORK_HOSTNAME_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="hostname" class="form-control input-sm" type="text" size="15" id="hostname" value="'. $bc -> get('root','hostname') .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				

				$tab."\t".'<hr>'. "\n" .
				$tab."\t".'<p class="text-center lead'. $simple_class .'" >'. NETWORK_ADVANCED_DIS .'</p>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'" id="lan_mtusize">'. "\n" .
				$tab."\t\t".'<label for="lan_mtu" class="col-sm-5 control-label">'. NETWORK_MTU_SIZE_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="lan_mtu" class="form-control input-sm" type="text" size="15" id="lan_mtu" title="'. NET_CONF_MTU_SIZE .'" data-toggle="tooltip" value="'. $bc -> get('root', 'lan-mtu') .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'">'. "\n" .
				$tab."\t\t".'<label for="beroAvahi-enabled" class="col-sm-5 control-label">'. NETWORK_AVAHI_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4 form-checkbox">'. "\n" .
				$tab."\t\t\t".'<input type="checkbox" name="beroAvahi-enabled" value="1" '. (($bc -> get('root', 'beroAvahi-enabled') == '1') ? 'checked' : '') .' />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'">'. "\n" .
				$tab."\t\t".'<label for="ncs_mode" class="col-sm-5 control-label">'. NETWORK_CONFIG_SERVER_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<select name="ncs_mode" class="form-control input-sm">'. "\n" .
				$tab."\t\t\t\t".'<option value="on" '. (($ncsDetectMode == 'on') ? 'selected="selected"' : '') .'>'. NETWORK_CONFIG_SERVER_OPTION_ON .'</option>'. "\n" .
				$tab."\t\t\t\t".'<option value="detectonly" '. (($ncsDetectMode == 'detectonly') ? 'selected="selected"' : '') .'>'. NETWORK_CONFIG_SERVER_OPTION_OD .'</option>'. "\n" .
				$tab."\t\t\t\t".'<option value="off" '. (($ncsDetectMode == 'off') ? 'selected="selected"' : '') .'>'. NETWORK_CONFIG_SERVER_OPTION_OFF .'</option>'. "\n" .
				$tab."\t\t\t".'</select>'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'">'. "\n" .
				$tab."\t\t".'<label for="vlanenable" class="col-sm-5 control-label">'. NETWORK_VLAN_ENABLE_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4 form-checkbox">'. "\n" .
				$tab."\t\t\t".'<input name="vlanenable" type="checkbox" id="vlanenable" onclick="show_vlan(document.getElementById(\'vlanenable\').checked);" value="1" '. (($bc -> get('root', 'vlan-enable') == 1) ? 'checked' : '') .'/>'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'" id="vlan_id">'. "\n" .
				$tab."\t\t".'<label for="vlanid" class="col-sm-5 control-label">'. NETWORK_VLAN_ID_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .
				$tab."\t\t\t".'<input name="vlanid" class="form-control input-sm" type="text" size="15" id="vlanid" value="'. $bc -> get('root', 'vlan-id') .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<div class="form-group '. $simple_class .'" id="vlan_prio">'. "\n" .
				$tab."\t\t".'<label for="vlan_prio" class="col-sm-5 control-label">'. NETWORK_VLAN_PRIORITY_DIS .'</label>'. "\n" .
				$tab."\t\t".'<div class="col-sm-4">'. "\n" .



				$this -> vlan_prio() . "\n" .



				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .



				$this -> routing($simple_class) . "\n" .

				$tab."\t".'<div class="form-group '. $simple_class .'" id="add_route">'. "\n" .
				$tab."\t\t".'<div class="text-center">'. "\n" .
				$tab."\t\t\t".'<input type="button" class="btn btn-default" id="add_route_button" value="'. BUTTON_ADD_ROUTE_ENTRY .'" />'. "\n" .
				$tab."\t\t".'</div>'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab."\t".'<br>'. "\n" .
				$tab."\t".'<div class="text-center">'. "\n" .
				$tab."\t\t".'<input type="submit" name="Apply" class="btn btn-default" value="'. BUTTON_SAVE .'" onmouseover="Tip(\''. NET_CONF_APPLY .'\')" onmouseout="UnTip()" />'. "\n" .
				$tab."\t".'</div>'. "\n" .
				$tab.'</form>'. "\n" .
				$tab.'<br>'. "\n" .
				$tab.'<div class="text-center" ><i>'. REQUIRED_FIELDS .'</i></div>'. "\n";

		$html_str .= "</div>";

		return $html_str;
	}

	/**
	 * 
	 * @return string HTML Seite
	 */
	function _display_tab2 ()
	{
		$html_str =	"\n\n" . '<!-- BEGIN TAB2 //-->' . "\n\n" .	
				"\t".'<div id="tabs-2">';

		$html_str .=	$this -> httpsSettingTable() . "\n" .
				"\t".'<script type="text/javascript" src="misc/script/netconf.js"></script>'. "\n";

		$html_str .=	"\n".'</div>' . "\n";

		return $html_str;
	}

	/**
	 * networking troubleshooting tools
	 * @return string network troubleshoot html
	 */
	function _display_tab3 ()
	{
		$html_str =		"\n\n" . '<!-- BEGIN TAB3 //-->' . "\n\n" .	
						"\t".'<div id="tabs-3">';
		$html_str .=	$this -> networkTroubleshootTable() . "\n";
		$html_str .=	"\n".'</div>' . "\n";
		
		return $html_str;
	}

	/**
	 * 
	 * @return string HTML Seite
	 */
	function display() {
		$name = "NETWORK_TITLE_DIS";
		include('./includes/header.php');
		include('/usr/fallback/beroConf.php');
		require_once('./includes/lang.php');

		$bc = new beroConf('root');
		$ba = new beroAri();

		if (!$bc->valid()) {
			$ret .= '<h3>Error:</h3><b>Failed to connect to config database!</b><br />';
			exit(0);
		}

		// args
		$m = $this->m_attr;

		// saving modification
		if ($this->post_checked && isset($this->post_attr['httpsOnly']) ) {
			$ret .= $this->save($ba, $bc);
		} else if ($this->post_checked) {
			if ($this->post_attr['dhcp'] == 'yes') {
				$ret .= $this->save($ba, $bc);
			} else {
				if ($this->post_attr['ipaddr'] != $this->post_attr['gateway']) {
					$result = exec('/usr/sbin/netconfigverify ' . $this->post_attr['ipaddr'] . ' ' . $this->post_attr['netmask'] . ' ' . $this->post_attr['gateway'] . ' 2>&1');
					if (substr_count($result, 'Failed') > 0) {
						$ret .= '<br /><div class="center"><b><font color="red">' . NETWORK_FAILED_ERROR_DIS . '</font></b></div>' . "\n";
					} else {
						$ret .= $this->save($ba, $bc);
					}
				} else {
					$ret .= '<br /><div class="center"><font color=red><b>' . NETWORK_FAILED_ERROR_DIS . '</b></font></div>' . "\n";
				}
			}
		} else if ($this->isRequestRejected) {
			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
		}


		//$iface = $bc->get('root', 'lan-iface');  // unused variable
		$dns = explode(';', $bc->get('root', 'lan-nameserver'));
		$dhcp = in_array($bc->get('root', 'lan-dhcp'), array('yes', '1'));

		if ($ba -> get('gui_mode') == 'simple')
		{
			$simple_class = 'simple';
		}

		$ncsDetectMode = $bc->get('root', 'ncs_mode');

		$ret .= $this -> _display_tabs($bc, $dhcp, $dns, $simple_class, $ncsDetectMode);

		return($ret);
	}

	/**
	 * @return string Checkbox httpsOnly
	 */

	function https_only() {
		$ba = new beroAri();
		$proxy_enable = $ba->get("httpsOnly");
		if ($proxy_enable == "1")
			return "<input type='hidden' name='httpsOnly' value='0'>"
				. "<input type='checkbox' name='httpsOnly' value='1' checked>";
		else
			return "<input type='hidden' name='httpsOnly' value='0'>"
				. "<input type='checkbox' name='httpsOnly' value='1'>";
	}

	/**
	 * 
	 * @return string HTML Formular mit den Https Einstellungen
	 */
	function httpsSettingTable() {
		ob_start();
		?>

		<form ENCTYPE="multipart/form-data" class="form-horizontal" action='' style="margin-top: 15px;" method='POST'>
			<input type="hidden" name="m" value="<?php echo $this->m_attr; ?>">
			<div class='form-group'>
				<label for='uploadfile' class='col-sm-5 control-label'><?php echo HTTPS_UPLOAD_CERTIFICATE_DIS; ?></label>
				<div class='col-sm-4 form-checkbox'>
					<input type='file' size='28' name='uploadfile'>
				</div>
			</div>
			<?php 	if (file_exists("/usr/conf/berofix.pem") && !is_link("/usr/conf/berofix.pem")): ?>
				<div class='form-group'>
					<label for='download' class='col-sm-5 control-label'><?php echo HTTPS_CERTIFICATE_DIS; ?></label>
					<div class='col-sm-4'>
						<input type='button' class='btn btn-default' value='<?php echo HTTPS_DOWNLOAD_CERTIFICATE_DIS; ?>'
							   onclick=" window.location.href = 'misc/files_download.php?option=certificate_https';">&nbsp;&nbsp;
						<input type='button' class='btn btn-default' value='<?php echo HTTPS_DELETE_CERTIFICATE_DIS; ?>'
							   onclick="javascript:if (confirm('<?php echo HTTPS_DELETE_CERTIFICATE_MESS_DIS; ?>?') == true)
			                                           window.location.href = 'misc/deletefile.php?m=<?php echo $this->m_attr; ?>&option=certificate_https';">
					</div>
				</div>
			<?php 	endif; 
				if (file_exists('/tmp/error_certificate.log'))
				{ ?>
			<div class='form-group'>			
				<label for='removeErrorCert' class='col-sm-5 control-label'><?php echo ERROR_HTTPS_REMOVE_CERTIFICATE_MESSAGE_DIS; ?></label>
				<div class='col-sm-4 form-checkbox'>
					<input type='checkbox' name='errorCert' value='1'/>
				</div>
			</div>
			<?php	} ?>
			<div class='form-group'>
				<label for='https_only' class='col-sm-5 control-label'><?php echo HTTPS_ONLY_DIS; ?></label>
				<div class='col-sm-4 form-checkbox'>
					<?php echo $this->https_only(); ?>
				</div>
			</div>

			<div class='text-center'>
				<br>
				<input name='submit' class='btn btn-default' type='submit' value='<?php echo BUTTON_SAVE; ?>'>
			</div>
		</form>
		<?php
		return ob_get_clean();
	}

	/**
	 * table with htmlnetwork tools
	 * @return string HTML network troubleshoot 
	 */
	function networkTroubleshootTable() {
		ob_start();
		?>

		<form name="nwtsform" id="nwtsform" ENCTYPE="multipart/form-data" class="form-horizontal" action='' style="margin-top: 15px;" method='POST'>				
			
			<div class="form-group" title="<?php echo NWTS_HOSTNAME_TT ?>" data-toggle="tooltip">
				<label for='nwts_hostName' class='col-sm-5 control-label'><?php echo NWTS_HOSTNAME_DIS ?></label>
				<div class='col-sm-5'>
					<input name='nwts_hostName' id='nwts_hostName' type='text' value="www.beronet.com" class='form-control input-sm'>
				</div>
			</div>
			<div class="form-group" title="<?php echo NWTS_PINGHOST_TT ?>" data-toggle="tooltip">
				<label for='nwts_pingHost' class='col-sm-5 control-label'><?php echo NWTS_PINGHOST_DIS ?></label>
				<div class='col-sm-4 form-checkbox' style="width: 1%">
					<input name='nwts_pingHost' id='nwts_pingHost' type='checkbox' value='1' checked>
				</div>
				<div class='col-sm-4 form-checkbox' id="res_pinghost">
				</div>
			</div>
			<div class="form-group" title="<?php echo NWTS_RESNAME_TT ?>" data-toggle="tooltip">
				<label for='nwts_resName' class='col-sm-5 control-label'><?php echo NWTS_RESNAME_DIS ?></label>
				<div class='col-sm-4 form-checkbox' style="width: 1%">
					<input name='nwts_resName' id='nwts_resName' type='checkbox' value='1' checked>
				</div>
				<div class='col-sm-4 form-checkbox' id="res_resname">
				</div>
			</div>
			<div class="form-group" title="<?php echo NWTS_HEALTH_TT ?>" data-toggle="tooltip">
				<label for='nwts_health' class='col-sm-5 control-label'><?php echo NWTS_HEALTH_DIS ?></label>
				<div class='col-sm-4 form-checkbox' style="width: 1%">
					<input name='nwts_health' id='nwts_health' type='checkbox' value='1' checked>
				</div>
				<div class='col-sm-4 form-checkbox' id="res_health">
				</div>
			</div>
			<div class="form-group" title="<?php echo NWTS_PUBIP_TT ?>" data-toggle="tooltip">
				<label for='nwts_getPubIP' class='col-sm-5 control-label'><?php echo NWTS_PUBIP_DIS ?></label>
				<div class='col-sm-4 form-checkbox' style="width: 1%">
					<input name='nwts_getPubIP' id='nwts_getPubIP' type='checkbox' value='1'>
				</div>
				<div class='col-sm-4 form-checkbox' id="res_pubic">
				</div>
			</div>

			<div id="nwtsWait" class="text-center" style="display: none">
				<img src="./includes/images/waitlogo1.gif">
			</div>
			<div id="nwtsButton" class="text-center" style="display: block">
				<input type="button" id="nwtsTest" class='btn btn-default' value='<?php echo BUTTON_TEST ?>'>
			</div>
			<br>

		</form>

		<?php
		return ob_get_clean();
	}

	/**
	 * 
	 * @return string Dropdown VLAN-Prio
	 */
	function vlan_prio() {

		$bc = new beroConf('root');

		$i = 0;
		$ret = '<select name="vlan-prio" class="form-control input-sm">' . "\n";
		foreach (array('000', '001', '010', '011', '100', '101', '110', '111') as $bit) {
			$ret .= '<option value="' . $bit . '"' . (($bc->get('root', 'vlan-prio') == $bit) ? ' selected' : '') . '>' . $i++ . '</option>' . "\n";
		}
		$ret .= '</select>' . "\n";

		return($ret);
	}

	/**
	 * @return string Gespeicherte Routen
	 */
	function routing($simple_class = null) {

		$bc = new beroConf('root');
		$routing = $bc->get('root', 'routing');

		if (strlen($routing) == 0) {
			return('');
		}

		$res = '';
		foreach (explode(',', $routing) as $route) {
			list($route_net, $route_netmask, $route_gateway) = explode('/', $route);
			ob_start();
			?>
			<div class='form-group <?php echo $simple_class; ?>' >
				<label for='route_net[]' class='col-sm-5 control-label'>Route target</label>
				<div class='col-sm-7'>
					<input name="route_net[]" verifyIP="true" class="net form-control input-sm" style="width:60%; display:inline;" 
						   value="<?php echo $route_net; ?>" />
					&nbsp;/&nbsp;
					<input name="route_netmask[]" digits="true" required="true" min="0" max="32" size="2" maxlength="2" style="width:20%; display:inline;" 
						   class="netmask form-control input-sm" value="<?php echo $route_netmask; ?>" />
				</div>
			</div>
			<div class='form-group <?php echo $simple_mode; ?>'>
				<label for='route_gateway[]' class='col-sm-5 control-label'>Route gateway</label>
				<div class='col-sm-4'>
					<input name="route_gateway[]" verifyIP="true" class="gateway form-control input-sm" value="<?php echo $route_gateway; ?>" size="24" />
				</div>
			</div>
			<?php
			$res .= ob_get_clean();
		}

		return($res);
	}

	private function _managePemFile($pem_file, &$option = null) {
		$check = array('punkt' => 'gruen', 'reason' => SIP_STACKS_UPLOAD_SUCCESS_DIS);

		exec("/usr/local/bin/openssl x509 -in $pem_file -noout -text", $output, $return_cert);
		exec("/usr/local/bin/openssl rsa -in $pem_file -check", $output, $return_privkey);

		if ($return_cert == 1) {
			// error with the certificate
			$check = array('punkt' => 'rot', 'reason' => HTTPS_INVALID_CERT_ERROR);
		}
		else if ($return_privkey == 1) {
			// error with the private key
			$check = array('punkt' => 'rot', 'reason' => HTTPS_INVALID_PRIVKEY_ERROR);
		}
		else {
			//check the certificates matches the private key
			exec("openssl x509 -modulus -noout -in $pem_file | openssl md5", $output_cert, $return_cert);
			exec("openssl rsa -modulus -noout -in $pem_file | openssl md5", $output_privkey, $return_privkey);

			if ($return_cert == 0 && $return_privkey == 0 && ($output_cert[0] == $output_privkey[0])) {
				// both certificate and private key are correct
				@unlink("/usr/conf/berofix.pem");
				exec("/bin/cp $pem_file /usr/conf/berofix.pem");
				$option = 3;
			}
			else {
				// certificate does not match with the private key
				$check = array('punkt' => 'rot', 'reason' => HTTPS_CERT_PRIVKEY_UNMATCH_ERROR);
			}
		}
		return "<div class='text-center'><img src='./includes/images/punkt_{$check['punkt']}.gif' /><font color='black'>{$check['reason']}</font></div>";
	}
}
?>
